@@ -251,9 +251,12 @@ class Table:
     total_usage: Optional[int] = None
     unique_usage: Optional[int] = None
     quality: Optional[str] = None
-    row_order: Optional[str] = None  # Predefine the order of the rows with a JSON value.
+    row_order: Optional[
+        str
+    ] = None  # Predefine the order of the rows with a JSON value.
     queries: Optional[List[Query]] = []
     creation_query: Optional[Query] = None
+    native_type: Optional[str] = None
 
 
 class TableSchema(AttrsSchema):
